Data one;
set clinepi.BERDPSA;
run;

Proc Contents data=one;
run;

/*Part 1a: Summary Statistics*/;

proc freq;
tables  died LSI VarPM GE55 Male VarLV VarINT VarHS VarCM VarCD VarSVH VarTS ;
run;

Proc means n nmiss min max mean std median;
var AgeP;
var DSev1;
var DSev2;
run;

/*Part 1b: Comparability (of prognostic factors/markers) between LSI groups*/;

proc freq;
tables (VarPM GE55 Male VarLV VarINT VarHS VarCM VarCD VarSVH VarTS  )*LSI/chisq;
run;

proc ttest;/*For instructional purposes only;
may need to compare medians instead*/
class LSI;
var AgeP;
var DSev1;
var DSev2;
run;

/*Part II: Traditional multivariable analysis*/;

ods rtf file='TMV.rtf';
proc logistic descending data=one;
class  GE55 (descending param=ref) Male(descending param=ref ) VarPM(descending param=ref) VarLV(descending param=ref) 
VarINT(descending param=ref) VarHS(descending param=ref ) VarCM (descending param=ref) VarCD (descending param=ref) VarSVH (descending param=ref)
VarTS(descending param=ref)  LSI(descending param=ref) SevDiz1 (descending param=ref) SevDiz2(descending param=ref);
*Model died = LSI VarPM GE55 Male VarLV VarINT VarHS VarCM VarCD VarSVH VarTS AgeP DSev1 DSev2/lackfit risklimits; /***FULL MODEL*/;
*Model died = LSI VarCM  VarSVH  AgeP DSev1 DSev2/lackfit risklimits; /***REDUCED FINAL MODEL*/;
Model died = LSI VarCM  VarSVH  AgeP DSev1 DSev2/lackfit risklimits; /***REDUCED FINAL MODEL*/;
roc; roccontrast;
run;
ods rtf close;


/* Part III: Propensity Score Model*/;
/*Note, one can leave interaction, quadratic terms, etc in the model.

Part IIIa: This step uses logistic regression to model the predicted
probability of receiving the intervention (LSI=1) */;
ods rtf file='psmod1.rtf';
proc logistic descending data=one;
class  GE55 (descending param=ref) Male(descending param=ref ) VarPM(descending param=ref) VarLV(descending param=ref) 
VarINT(descending param=ref) VarHS(descending param=ref ) VarCM (descending param=ref) VarCD (descending param=ref) VarSVH (descending param=ref)
VarTS(descending param=ref)  LSI(descending param=ref);

*Model LSI = VarPM GE55 Male VarLV VarINT VarHS VarCM VarCD VarSVH VarTS AgeP DSev1 DSev2/lackfit risklimits; /***FULL MODEL*/;
Model LSI = VarPM  VarLV VarINT VarHS  VarSVH VarTS AgeP DSev1 DSev2 /lackfit risklimits; /***REDUCED FINAL MODEL*/;

output out=probs h=hat  p=pscore xbeta=logit;
roc; roccontrast;
run;
ods rtf close;

/*Part IIIb:Obtain probabilities that define quintiles*/
proc rank data=probs groups=5 out=ranks;
ranks quintile;
var pscore;
run;
/* Part IIIb: Check distribution of scores by LSI group across quintiles*/;
 *ods rtf file='dist.rtf';
proc freq data=ranks ;
tables quintile*LSI/chisq norow nopct;
run;
*ods rtf close;

proc freq data=ranks ;
tables quintile*died/chisq norow nopct;
run;

/*Note there are no deaths in quintile 0*/;

/*Part IIId: Effectiveness of PS as a balancing score - Significance Testing*/;

proc logistic descending data=ranks;
class  GE55 (descending param=ref) Male(descending param=ref ) VarPM(descending param=ref) VarLV(descending param=ref) 
VarINT(descending param=ref) VarHS(descending param=ref ) VarCM (descending param=ref) VarCD (descending param=ref) VarSVH (descending param=ref)
VarTS(descending param=ref)  LSI(descending param=ref);

model LSI = AgeP quintile/lackfit risklimits;
*model LSI =  VarPM quintile /lackfit risklimits; 
*model LSI = GE55 quintile/lackfit risklimits;
*model LSI = Male quintile/lackfit risklimits;
*model LSI = VarLV quintile/lackfit risklimits;
*model LSI = VarINT quintile/lackfit risklimits;
*model LSI = VarHS quintile/lackfit risklimits;
*model LSI = VarCM quintile/lackfit risklimits;
*model LSI = VarCD quintile/lackfit risklimits;
*model LSI = VarSVH quintile/lackfit risklimits;
*model LSI = VarTS quintile/lackfit risklimits;
*model LSI =  DSev1 quintile/lackfit risklimits;
*model LSI =  DSev2 quintile/lackfit risklimits;
*model LSI = DSev1 pscore/lackfit risklimits;
*model LSI = DSev2 pscore/lackfit risklimits;
run;

