
/*obtain probabilities that define quintiles*/
proc rank data=probs groups=5 out=ranks;
ranks quintile;
var pscore;
run;

proc sort data=ranks out=ranks2;
  by quintile; 
run;
proc means noprint max data=ranks2;
  by quintile;
  var pscore;
  output out=test max=qphat;
run;
proc transpose data=test (where=(quintile in (0,1,2,3))) out=ranks3;
  var qphat;
run;
proc print data=ranks3;
run;
/*copy and paste probabilities from data RRRR
into HREF statement in PROC GPLOT BELOW.*/

/*Part IIIc: Graphical assessement of score distribution*/;

/*a simple "jittering" that adds a small value to
the basic 0 and 1 values to spread them out.*/
data plot;
set probs (keep=pscore LSI);
if LSI=0 then do;
  Interv=LSI + 0.45*ranuni(12345);
end;
else if LSI=1 then do;
  Interv=LSI - 0.45*ranuni(12345);
end;
run;

proc format;
  value LSI 0="NO" 1="YES";
run;

goptions reset=all ftext=swissb htext=1.5;
proc gplot data=plot;
axis1 label=('Propensity Score')
      offset=(.3 cm)  value=(h=1.5)  minor=none;
axis2 order=0 to 1 offset=(1 cm)  
      value=(h=2) 
      label=(a=90 h=2 'Recieved Intervention') ;
symbol c=black v=DIAMOND h=1.3 i=none;
plot Interv*pscore  /haxis=axis1 vaxis=axis2 
                 href= 0.21352 0.28036 0.38239 0.53343 
                 whref=2 chref=darkblue;
Title 'Figure X. Propensity Scores by Intervention Status';
format Interv LSI.;
run;
end;

/*A quick set of histograms that compare the distributions
  of propensity scores for the two groups and lets you visualize
  their overlap*/
data probs;
  set probs;
  label pscore="Propensity Score";
run;
proc univariate data=probs noprint;
  class LSI;
  var pscore;
  histogram pscore /  endpoints=.1 to 1 by .1;

run;

/*This butterfly plot works using the dataset
called PROBS*/

proc univariate data=probs (keep=pscore LSI) noprint;
  class LSI;
  var pscore;
  histogram pscore / midpercents endpoints=.1 to 1 by .1;
  ods output histogrambins=plotb;
run;

proc sort data=plotb;
  by minpoint;
run;
data plotb2;
  array pp [2] perc0 perc1;
  set plotb (keep=LSI minpoint obspercent);
  if LSI=0 then obspercent=-1*obspercent;
  by minpoint ;
  retain perc0;
  pp[LSI+1]=obspercent;
  if LSI=1;
run;
proc format;
   picture positive 
     low-<0='000,000'
     0<-high='000,000';
run;
proc template;
  source styles.default;
run;
goptions reset=all;
proc sgplot data=plotb2;
   format perc0 perc1 positive.;
   vbar minpoint / response=perc0 
        fillattrs=graphdata1 transparency=.50 barwidth=1
        legendlabel="Did Not Receive Intervention" name="g" ;
   vbar minpoint / response=perc1  
        fillattrs=graphdata1 transparency=.30 barwidth=1
        legendlabel="Received Intervention" name="h" ;
   keylegend "h" "g" 
        / noborder down=2 location=inside position=bottomright
          valueattrs=(size=15 weight=bold);
   xaxis label="Propensity Scores" 
         valueattrs=(size=12 weight=bold)
         labelattrs=(size=12 weight=bold);
   yaxis label="Percent"
         discreteorder=data
		 valueattrs=(size=10 weight=bold)
         labelattrs=(size=12 weight=bold);
run;
